![Python package build and test](https://github.com/software-students-spring2024/3-python-package-exercise-speed/actions/workflows/build.yaml/badge.svg)

# PyDancer

Python game version of dance arcade games. To play, use the arrow keys to match the steps of the dance.

Note: When writing the statements below, you may need to change all the statements with `python3` to `python` depending on your python installation. 

## To play:
`python3 -m pydancer play`

To change the song, difficulty, and character,

`python3 -m pydancer play --song two-in-the-rain --difficulty hard --character boy`

## To list play options:
To list all play options,

`python3 -m pydancer options`

To list only character options,

`python3 -m pydancer options --characters`

To list only difficulty options,

`python3 -m pydancer options --difficulties`

## To list songs:
To list all songs,

`python3 -m pydancer songs`

To list songs by genre, for example rock,

`python3 -m pydancer songs --genre rock`

## To print how-to guide:
To print the short how-to guide,

`python3 -m pydancer how-to`

To print the long how-to guide,

`python3 -m pydancer how-to --long`


## Contributing

We welcome contributions from everyone! Before contributing, please read our [Contribution Guidelines](https://github.com/software-students-spring2024/3-python-package-exercise-speed/blob/main/CONTRIBUTING.md) to understand our contribution process.

If you find a bug or have a feature request, please open an issue on our [Issue Tracker](https://github.com/software-students-spring2024/3-python-package-exercise-speed/issues).

## Contributors
- [Glenda Boeker](https://github.com/gboeker)
- [Shriya Kalakata](https://github.com/shriyakalakata)
- [Ahmet Ilten](https://github.com/iltenahmet)
- [Amber Li](https://github.com/al6862)
